@@ -20,87 +20,6 @@ literals = LiteralsCore([DotnetLiterals])
 commands = CommandsCore([DotnetCommands])
 
 
-def drop_database(startup_project_path: str, environment: str, no_build: bool = False):
-    """ Drops the database
-
-    Args:
-        startup_project_path: Path to the startup project
-        environment: Name for the environment to get the migrations for
-        no_build: Skips build if True
-    """
-    logging.info(literals.get("dotnet_ef_database_drop"))
-
-    result: str = cli.call_subprocess_with_result(commands.get("dotnet_ef_database_drop").format(
-        path=startup_project_path,
-        no_build="--no-build" if no_build else "",
-        env=environment
-    ))
-    logging.info(result)
-
-
-def generate_migration_sql_script(startup_project_path: str, environment: str, script_path: str):
-    """ Generates SQL migration script for a specific environment
-
-    Args:
-        startup_project_path: Path to the startup project.
-        environment: Name for the environment to get the migrations for.
-        script_path: Path to the SQL script to be generated.
-    """
-
-    migrations_list: list = __get_migrations_list(startup_project_path, environment)
-    migration_name, migration_date = __get_first_migration_not_applied(migrations_list)
-    migrations, applied_migrations, last_migration_applied = __parse_data_from_migrations_json_array(migrations_list)
-
-    if migration_name is not None and migrations != applied_migrations:
-        __generate_sql_script(
-            startup_project_path, script_path.replace("#date#", migration_date), environment, last_migration_applied)
-
-
-def generate_migration_sql_scripts_for_all_environments(
-        startup_project_path: str, scripts_base_path: str, include_development: bool = False):
-    """ Generates a SQL migration script for every environment configured in
-    the appsettings.*.json files.
-
-    Args:
-        startup_project_path: Path to the startup project.
-        scripts_base_path: Path to the directory where all scripts will be
-            created at.
-        include_development: If True, Development/Dev is included in the list.
-    """
-
-    environments = utils.get_appsettings_environments(startup_project_path, include_development)
-    logging.info(literals.get("dotnet_ef_got_environments").format(environments=environments))
-
-    base_path_obj = pathlib.Path(scripts_base_path)
-
-    for environment in environments:
-        logging.info(literals.get("dotnet_ef_script_for_environment").format(environment=environment))
-
-        script_path = pathlib.Path.joinpath(base_path_obj, f"database-migration-{environment.lower()}-from-#date#.sql")
-        logging.info(literals.get("dotnet_ef_script_being_generated").format(script_path=script_path))
-
-        generate_migration_sql_script(startup_project_path, environment, str(script_path))
-
-
-def reset_database(startup_project_path: str, environment: str, no_build: bool = False):
-    """ Reverts all migrations applied, dropping all tables and truncating
-    __efmigrationshistory database
-
-    Args:
-        startup_project_path: Path to the startup project.
-        environment: Name for the environment to get the migrations for.
-        no_build: Skips build if True.
-    """
-    logging.info(literals.get("dotnet_ef_database_reset"))
-
-    result: str = cli.call_subprocess_with_result(commands.get("dotnet_ef_database_reset").format(
-        path=startup_project_path,
-        no_build="--no-build" if no_build else "",
-        env=environment
-    ))
-    logging.info(result)
-
-
 def __generate_sql_script(startup_project_path: str, script_path: str, environment: str,
                           migration_from: str = "0", no_build: bool = False, idempotent: bool = True):
     """ Generates a SQL script to apply ad hoc migrations to DBMS
@@ -212,5 +131,107 @@ def __parse_data_from_migrations_json_array(migrations_json_array: list) -> (int
     return len(migrations_json_array), applied_migrations, last_applied_migration
 
 
+def check_branch_suitableness_for_migrations(
+        current_simplified_branch: str, suitable_branches: list,
+        environment_variable_name: str = "DT_SUITABLE_BRANCH_FOR_MIGRATIONS") -> bool:
+    """Checks if the current Git branch is suitable for generating and applying
+    SQL migration scripts.
+
+    Args:
+        current_simplified_branch: Current simplified Git branch.
+        suitable_branches: List of branches that are suitable for migrations.
+        environment_variable_name: Name of the environment variable to be
+            created. Defaults to "DT_SUITABLE_BRANCH_FOR_MIGRATIONS".
+
+    Returns:
+        True if branch is suitable, False otherwise.
+    """
+
+    is_suitable = True if current_simplified_branch in suitable_branches else False
+    platform_specific.create_environment_variables({environment_variable_name: is_suitable})
+    return is_suitable
+
+
+def drop_database(startup_project_path: str, environment: str, no_build: bool = False):
+    """ Drops the database
+
+    Args:
+        startup_project_path: Path to the startup project
+        environment: Name for the environment to get the migrations for
+        no_build: Skips build if True
+    """
+    logging.info(literals.get("dotnet_ef_database_drop"))
+
+    result: str = cli.call_subprocess_with_result(commands.get("dotnet_ef_database_drop").format(
+        path=startup_project_path,
+        no_build="--no-build" if no_build else "",
+        env=environment
+    ))
+    logging.info(result)
+
+
+def generate_migration_sql_script(startup_project_path: str, environment: str, script_path: str):
+    """ Generates SQL migration script for a specific environment
+
+    Args:
+        startup_project_path: Path to the startup project.
+        environment: Name for the environment to get the migrations for.
+        script_path: Path to the SQL script to be generated.
+    """
+
+    migrations_list: list = __get_migrations_list(startup_project_path, environment)
+    migration_name, migration_date = __get_first_migration_not_applied(migrations_list)
+    migrations, applied_migrations, last_migration_applied = __parse_data_from_migrations_json_array(migrations_list)
+
+    if migration_name is not None and migrations != applied_migrations:
+        __generate_sql_script(
+            startup_project_path, script_path.replace("#date#", migration_date), environment, last_migration_applied)
+
+
+def generate_migration_sql_scripts_for_all_environments(
+        startup_project_path: str, scripts_base_path: str, include_development: bool = False):
+    """ Generates a SQL migration script for every environment configured in
+    the appsettings.*.json files.
+
+    Args:
+        startup_project_path: Path to the startup project.
+        scripts_base_path: Path to the directory where all scripts will be
+            created at.
+        include_development: If True, Development/Dev is included in the list.
+    """
+
+    environments = utils.get_appsettings_environments(startup_project_path, include_development)
+    logging.info(literals.get("dotnet_ef_got_environments").format(environments=environments))
+
+    base_path_obj = pathlib.Path(scripts_base_path)
+
+    for environment in environments:
+        logging.info(literals.get("dotnet_ef_script_for_environment").format(environment=environment))
+
+        script_path = pathlib.Path.joinpath(base_path_obj, f"database-migration-{environment.lower()}-from-#date#.sql")
+        logging.info(literals.get("dotnet_ef_script_being_generated").format(script_path=script_path))
+
+        generate_migration_sql_script(startup_project_path, environment, str(script_path))
+
+
+def reset_database(startup_project_path: str, environment: str, no_build: bool = False):
+    """ Reverts all migrations applied, dropping all tables and truncating
+    __efmigrationshistory database
+
+    Args:
+        startup_project_path: Path to the startup project.
+        environment: Name for the environment to get the migrations for.
+        no_build: Skips build if True.
+    """
+    logging.info(literals.get("dotnet_ef_database_reset"))
+
+    result: str = cli.call_subprocess_with_result(commands.get("dotnet_ef_database_reset").format(
+        path=startup_project_path,
+        no_build="--no-build" if no_build else "",
+        env=environment
+    ))
+    logging.info(result)
+
+
 if __name__ == "__main__":
     help(__name__)
